<?php

/**
 * Class for all wcboost wishlist template modification
 *
 * @version 1.0
 */

/**
 * Ajaxify update count wishlist
 *
 * @since 1.0
 *
 * @param array $fragments
 *
 * @return array
 */
function update_wishlist_count($data) {
	$data['.menu-item-wishlist .mini-cart-counter'] = '<span class="mini-cart-counter">'.\WCBoost\Wishlist\Helper::get_wishlist()->count_items() . '</span>';

	return $data;
}

add_filter( 'wcboost_wishlist_add_to_wishlist_fragments', 'update_wishlist_count', 10, 1 );

/**
 * Change button view text
 *
 * @return void
 */
function wishlist_button_view_text() {
	return esc_html__( 'Browse wishlist', 'unero' );
}

add_filter( 'wcboost_wishlist_button_view_text', 'wishlist_button_view_text' );

/**
 * Wishlist array
 *
 * @since 1.0.0
 *
 * @return array
 */
function wishlist_args($args) {
	if( $key = array_search( 'button', $args['class'] ) ) {
		unset( $args['class'][$key] );
	}

	return $args;
}

add_filter( 'wcboost_wishlist_button_template_args', 'wishlist_args', 20, 3 );

/**
 * Wishlist icon
 *
 * @since 1.0.0
 *
 * @return void
 */
function wishlist_svg_icon($svg, $icon) {
	if ( $icon == 'heart' ) {
		$svg = '<svg viewBox="0 0 32 32">
		<path d="M29.45 4.2c-1.65-1.75-3.85-2.7-6.2-2.7s-4.55 0.95-6.2 2.7l-1.1 1.15-1.1-1.2c-1.7-1.65-3.95-2.6-6.2-2.6-3.25 0-6.1 1.75-7.65 4.8-1.8 3.55-1.1 8.1 1.7 11.15l11.55 12.25c0.45 0.5 1.1 0.75 1.75 0.75 0 0 0 0 0 0 0.65 0 1.3-0.3 1.75-0.8l11.7-12.55c1.65-1.75 2.55-4.050 2.55-6.5s-0.9-4.75-2.55-6.45zM28.4 16.15l-11.75 12.55c-0.15 0.2-0.4 0.3-0.65 0.3 0 0 0 0 0 0-0.25 0-0.5-0.1-0.65-0.3l-11.55-12.25c-2.4-2.55-3-6.45-1.45-9.45 1.3-2.5 3.65-4 6.3-4 1.85 0 3.7 0.8 5.050 2.2l2.2 2.35 2.2-2.35c1.4-1.4 3.2-2.2 5.15-2.2s3.75 0.8 5.1 2.25c1.4 1.45 2.15 3.4 2.15 5.45s-0.75 4-2.1 5.45z"></path>
		</svg>';
	} else if ( $icon == 'heart-filled' ) {
		$svg = '<svg viewBox="0 0 32 32">
		<path d="M29.55 4.45c-3.25-3.25-8.6-3.25-11.85 0l-1.75 1.75-1.75-1.75c-1.65-1.6-3.75-2.4-5.9-2.4s-4.25 0.75-5.85 2.4c-3.25 3.25-3.25 8.65 0 11.9l13.55 13.65 13.55-13.7c1.65-1.65 2.45-3.75 2.45-5.9s-0.85-4.35-2.45-5.95z"></path>
		</svg>';
	}

	return $svg;
}

add_filter( 'wcboost_wishlist_svg_icon', 'wishlist_svg_icon', 20, 3 );

/**
 * Wishlist table
 *
 * @return void
 */
function wishlist_table( $item, $item_key, $wishlist ) {
	$_product = $item->get_product();
	$default_columns  = [
		'price'    => 'yes',
		'stock'    => 'yes',
		'quantity' => 'no',
		'date'     => 'no',
		'purchase' => 'yes',
	];

	$columns = get_option( 'wcboost_wishlist_table_columns' , $default_columns );
	$columns = wp_parse_args( $columns, $default_columns );
	?>
		<?php if( isset( $columns['price'] ) && $columns['price'] == 'yes' ) : ?>
			<div class="product-price hidden-lg hidden-md">
				<span class="label"><?php esc_html_e( 'Price', 'unero' ); ?></span>
				<span class="price"><?php echo wp_kses_post( $_product->get_price_html() ); ?></span>
			</div>
		<?php endif; ?>

		<?php if( isset( $columns['stock'] ) && $columns['stock'] == 'yes' ) : ?>
			<div class="product-stock-status hidden-lg hidden-md">
				<span class="label"><?php esc_html_e( 'Stock', 'unero' ); ?></span>
				<?php
				$availability = $_product->get_availability();
				printf( '<span class="%s">%s</span>', esc_attr( $availability['class'] ), $availability['availability'] ? esc_html( $availability['availability'] ) : esc_html__( 'In Stock', 'unero' ) );
				?>
			</div>
		<?php endif; ?>

		<?php if ( isset( $columns['date'] ) && $columns['date'] == 'yes' ) : ?>
			<div class="product-date hidden-lg hidden-md">
				<?php echo esc_html( $item->get_date_added()->format( get_option( 'date_format' ) ) ); ?>
			</div>
		<?php endif; ?>
	<?php
}

add_action( 'wcboost_wishlist_after_item_name', 'wishlist_table', 10, 3 );